#[repr(C)]pub struct AxisF {
pub range: RangeF,
pub resolution: f32,
pub scale: AxisScale,
}Fields
range: RangeFresolution: f32scale: AxisScaleTrait Implementations
impl Copy for AxisF
Sourceimpl<___E> Encode<AxisF, ___E> for AxisFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AxisF, ___E> for AxisFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, AxisF>
const COPY_OPTIMIZATION: CopyOptimization<Self, AxisF>
Sourceimpl<'a, ___E> Encode<AxisF, ___E> for &'a AxisFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AxisF, ___E> for &'a AxisFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> EncodeOption<Box<'static, AxisF>, ___E> for AxisF
impl<___E> EncodeOption<Box<'static, AxisF>, ___E> for AxisF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AxisF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AxisF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, AxisF>, ___E> for &'a AxisF
impl<'a, ___E> EncodeOption<Box<'static, AxisF>, ___E> for &'a AxisF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AxisF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AxisF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<AxisF> for AxisF
impl FromWireRef<AxisF> for AxisF
Sourcefn from_wire_ref(wire: &AxisF) -> Self
fn from_wire_ref(wire: &AxisF) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for AxisF
impl PartialOrd for AxisF
impl StructuralPartialEq for AxisF