pub struct DeviceIteratorGetNextResponse {
pub devices: Vec<DeviceEvent>,
}Fields
devices: Vec<DeviceEvent>Trait Implementations
Sourceimpl Clone for DeviceIteratorGetNextResponse
impl Clone for DeviceIteratorGetNextResponse
Sourcefn clone(&self) -> DeviceIteratorGetNextResponse
fn clone(&self) -> DeviceIteratorGetNextResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<DeviceIteratorGetNextResponse<'static>, ___E> for DeviceIteratorGetNextResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceIteratorGetNextResponse<'static>, ___E> for DeviceIteratorGetNextResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceIteratorGetNextResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceIteratorGetNextResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<DeviceIteratorGetNextResponse<'static>, ___E> for &'a DeviceIteratorGetNextResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceIteratorGetNextResponse<'static>, ___E> for &'a DeviceIteratorGetNextResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceIteratorGetNextResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceIteratorGetNextResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceIteratorGetNextResponse<'static>>, ___E> for DeviceIteratorGetNextResponsewhere
___E: Encoder + ?Sized,
DeviceIteratorGetNextResponse: Encode<DeviceIteratorGetNextResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceIteratorGetNextResponse<'static>>, ___E> for DeviceIteratorGetNextResponsewhere
___E: Encoder + ?Sized,
DeviceIteratorGetNextResponse: Encode<DeviceIteratorGetNextResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceIteratorGetNextResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceIteratorGetNextResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceIteratorGetNextResponse<'static>>, ___E> for &'a DeviceIteratorGetNextResponsewhere
___E: Encoder + ?Sized,
&'a DeviceIteratorGetNextResponse: Encode<DeviceIteratorGetNextResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceIteratorGetNextResponse<'static>>, ___E> for &'a DeviceIteratorGetNextResponsewhere
___E: Encoder + ?Sized,
&'a DeviceIteratorGetNextResponse: Encode<DeviceIteratorGetNextResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceIteratorGetNextResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceIteratorGetNextResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceIteratorGetNextResponse<'de>> for DeviceIteratorGetNextResponse
impl<'de> FromWire<DeviceIteratorGetNextResponse<'de>> for DeviceIteratorGetNextResponse
Sourcefn from_wire(wire: DeviceIteratorGetNextResponse<'de>) -> Self
fn from_wire(wire: DeviceIteratorGetNextResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceIteratorGetNextResponse<'de>> for DeviceIteratorGetNextResponse
impl<'de> FromWireRef<DeviceIteratorGetNextResponse<'de>> for DeviceIteratorGetNextResponse
Sourcefn from_wire_ref(wire: &DeviceIteratorGetNextResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceIteratorGetNextResponse<'de>) -> Self
Converts the given reference to this type.
impl StructuralPartialEq for DeviceIteratorGetNextResponse