pub struct FocusEvent {
pub event_time: u64,
pub focused: bool,
}Fields
event_time: u64focused: boolTrait Implementations
Sourceimpl Clone for FocusEvent
impl Clone for FocusEvent
Sourcefn clone(&self) -> FocusEvent
fn clone(&self) -> FocusEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FocusEvent
Sourceimpl Debug for FocusEvent
impl Debug for FocusEvent
Sourceimpl<___E> Encode<FocusEvent, ___E> for FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FocusEvent, ___E> for FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocusEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocusEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<FocusEvent, ___E> for &'a FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FocusEvent, ___E> for &'a FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocusEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocusEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, FocusEvent>, ___E> for FocusEvent
impl<___E> EncodeOption<Box<'static, FocusEvent>, ___E> for FocusEvent
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FocusEvent>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FocusEvent>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, FocusEvent>, ___E> for &'a FocusEvent
impl<'a, ___E> EncodeOption<Box<'static, FocusEvent>, ___E> for &'a FocusEvent
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FocusEvent>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FocusEvent>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for FocusEvent
Sourceimpl FromWire<FocusEvent> for FocusEvent
impl FromWire<FocusEvent> for FocusEvent
Sourcefn from_wire(wire: FocusEvent) -> Self
fn from_wire(wire: FocusEvent) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FocusEvent> for FocusEvent
impl FromWireRef<FocusEvent> for FocusEvent
Sourcefn from_wire_ref(wire: &FocusEvent) -> Self
fn from_wire_ref(wire: &FocusEvent) -> Self
Converts the given reference to this type.
Sourceimpl Hash for FocusEvent
impl Hash for FocusEvent
Sourceimpl Ord for FocusEvent
impl Ord for FocusEvent
Sourcefn cmp(&self, other: &FocusEvent) -> Ordering
fn cmp(&self, other: &FocusEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for FocusEvent
impl PartialEq for FocusEvent
Sourceimpl PartialOrd for FocusEvent
impl PartialOrd for FocusEvent
impl StructuralPartialEq for FocusEvent