#[repr(C)]pub struct InputMethodEditorDispatchKey3Response {
pub handled: bool,
}Fields
handled: boolTrait Implementations
Sourceimpl Clone for InputMethodEditorDispatchKey3Response
impl Clone for InputMethodEditorDispatchKey3Response
Sourcefn clone(&self) -> InputMethodEditorDispatchKey3Response
fn clone(&self) -> InputMethodEditorDispatchKey3Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for InputMethodEditorDispatchKey3Response
Sourceimpl<___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, InputMethodEditorDispatchKey3Response>
const COPY_OPTIMIZATION: CopyOptimization<Self, InputMethodEditorDispatchKey3Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for &'a InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for &'a InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Response>, ___E> for InputMethodEditorDispatchKey3Responsewhere
___E: Encoder + ?Sized,
InputMethodEditorDispatchKey3Response: Encode<InputMethodEditorDispatchKey3Response, ___E>,
impl<___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Response>, ___E> for InputMethodEditorDispatchKey3Responsewhere
___E: Encoder + ?Sized,
InputMethodEditorDispatchKey3Response: Encode<InputMethodEditorDispatchKey3Response, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Response>, ___E> for &'a InputMethodEditorDispatchKey3Responsewhere
___E: Encoder + ?Sized,
&'a InputMethodEditorDispatchKey3Response: Encode<InputMethodEditorDispatchKey3Response, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Response>, ___E> for &'a InputMethodEditorDispatchKey3Responsewhere
___E: Encoder + ?Sized,
&'a InputMethodEditorDispatchKey3Response: Encode<InputMethodEditorDispatchKey3Response, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for InputMethodEditorDispatchKey3Response
Sourceimpl FromWire<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
impl FromWire<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputMethodEditorDispatchKey3Response, Self>
const COPY_OPTIMIZATION: CopyOptimization<InputMethodEditorDispatchKey3Response, Self>
Sourcefn from_wire(wire: InputMethodEditorDispatchKey3Response) -> Self
fn from_wire(wire: InputMethodEditorDispatchKey3Response) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
impl FromWireRef<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
Sourcefn from_wire_ref(wire: &InputMethodEditorDispatchKey3Response) -> Self
fn from_wire_ref(wire: &InputMethodEditorDispatchKey3Response) -> Self
Converts the given reference to this type.
Sourceimpl Ord for InputMethodEditorDispatchKey3Response
impl Ord for InputMethodEditorDispatchKey3Response
Sourcefn cmp(&self, other: &InputMethodEditorDispatchKey3Response) -> Ordering
fn cmp(&self, other: &InputMethodEditorDispatchKey3Response) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for InputMethodEditorDispatchKey3Response
impl PartialOrd for InputMethodEditorDispatchKey3Response
impl StructuralPartialEq for InputMethodEditorDispatchKey3Response