pub struct InputMethodEditorSetStateRequest {
pub state: TextInputState,
}Fields
state: TextInputStateTrait Implementations
Sourceimpl Clone for InputMethodEditorSetStateRequest
impl Clone for InputMethodEditorSetStateRequest
Sourcefn clone(&self) -> InputMethodEditorSetStateRequest
fn clone(&self) -> InputMethodEditorSetStateRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<InputMethodEditorSetStateRequest<'static>, ___E> for InputMethodEditorSetStateRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<InputMethodEditorSetStateRequest<'static>, ___E> for InputMethodEditorSetStateRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorSetStateRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorSetStateRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<InputMethodEditorSetStateRequest<'static>, ___E> for &'a InputMethodEditorSetStateRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<InputMethodEditorSetStateRequest<'static>, ___E> for &'a InputMethodEditorSetStateRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorSetStateRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorSetStateRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputMethodEditorSetStateRequest<'static>>, ___E> for InputMethodEditorSetStateRequestwhere
___E: Encoder + ?Sized,
InputMethodEditorSetStateRequest: Encode<InputMethodEditorSetStateRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InputMethodEditorSetStateRequest<'static>>, ___E> for InputMethodEditorSetStateRequestwhere
___E: Encoder + ?Sized,
InputMethodEditorSetStateRequest: Encode<InputMethodEditorSetStateRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorSetStateRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorSetStateRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorSetStateRequest<'static>>, ___E> for &'a InputMethodEditorSetStateRequestwhere
___E: Encoder + ?Sized,
&'a InputMethodEditorSetStateRequest: Encode<InputMethodEditorSetStateRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorSetStateRequest<'static>>, ___E> for &'a InputMethodEditorSetStateRequestwhere
___E: Encoder + ?Sized,
&'a InputMethodEditorSetStateRequest: Encode<InputMethodEditorSetStateRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorSetStateRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorSetStateRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for InputMethodEditorSetStateRequest
Sourceimpl<'de> FromWire<InputMethodEditorSetStateRequest<'de>> for InputMethodEditorSetStateRequest
impl<'de> FromWire<InputMethodEditorSetStateRequest<'de>> for InputMethodEditorSetStateRequest
Sourcefn from_wire(wire: InputMethodEditorSetStateRequest<'de>) -> Self
fn from_wire(wire: InputMethodEditorSetStateRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputMethodEditorSetStateRequest<'de>> for InputMethodEditorSetStateRequest
impl<'de> FromWireRef<InputMethodEditorSetStateRequest<'de>> for InputMethodEditorSetStateRequest
Sourcefn from_wire_ref(wire: &InputMethodEditorSetStateRequest<'de>) -> Self
fn from_wire_ref(wire: &InputMethodEditorSetStateRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for InputMethodEditorSetStateRequest
impl Ord for InputMethodEditorSetStateRequest
Sourcefn cmp(&self, other: &InputMethodEditorSetStateRequest) -> Ordering
fn cmp(&self, other: &InputMethodEditorSetStateRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for InputMethodEditorSetStateRequest
impl PartialOrd for InputMethodEditorSetStateRequest
impl StructuralPartialEq for InputMethodEditorSetStateRequest