#[repr(C)]pub struct MouseReport {
pub rel_x: i32,
pub rel_y: i32,
pub rel_hscroll: i32,
pub rel_vscroll: i32,
pub pressed_buttons: u32,
}Fields
rel_x: i32rel_y: i32rel_hscroll: i32rel_vscroll: i32Trait Implementations
Sourceimpl Clone for MouseReport
impl Clone for MouseReport
Sourcefn clone(&self) -> MouseReport
fn clone(&self) -> MouseReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MouseReport
Sourceimpl Debug for MouseReport
impl Debug for MouseReport
Sourceimpl<___E> Encode<MouseReport, ___E> for MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MouseReport, ___E> for MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MouseReport>
const COPY_OPTIMIZATION: CopyOptimization<Self, MouseReport>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MouseReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MouseReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<MouseReport, ___E> for &'a MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MouseReport, ___E> for &'a MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MouseReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MouseReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, MouseReport>, ___E> for MouseReport
impl<___E> EncodeOption<Box<'static, MouseReport>, ___E> for MouseReport
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MouseReport>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MouseReport>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MouseReport>, ___E> for &'a MouseReport
impl<'a, ___E> EncodeOption<Box<'static, MouseReport>, ___E> for &'a MouseReport
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MouseReport>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MouseReport>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for MouseReport
Sourceimpl FromWire<MouseReport> for MouseReport
impl FromWire<MouseReport> for MouseReport
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MouseReport, Self>
const COPY_OPTIMIZATION: CopyOptimization<MouseReport, Self>
Sourcefn from_wire(wire: MouseReport) -> Self
fn from_wire(wire: MouseReport) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<MouseReport> for MouseReport
impl FromWireRef<MouseReport> for MouseReport
Sourcefn from_wire_ref(wire: &MouseReport) -> Self
fn from_wire_ref(wire: &MouseReport) -> Self
Converts the given reference to this type.
Sourceimpl Hash for MouseReport
impl Hash for MouseReport
Sourceimpl Ord for MouseReport
impl Ord for MouseReport
Sourcefn cmp(&self, other: &MouseReport) -> Ordering
fn cmp(&self, other: &MouseReport) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MouseReport
impl PartialEq for MouseReport
Sourceimpl PartialOrd for MouseReport
impl PartialOrd for MouseReport
impl StructuralPartialEq for MouseReport