pub struct PointerEvent {
pub event_time: u64,
pub device_id: u32,
pub pointer_id: u32,
pub type_: PointerEventType,
pub phase: PointerEventPhase,
pub x: f32,
pub y: f32,
pub radius_major: f32,
pub radius_minor: f32,
pub buttons: u32,
}Expand description
Pointers represent raw data about the user’s interaction with the screen.
The state transitions should be as follows: ADD (-> HOVER) -> DOWN -> MOVE -> UP (-> HOVER) -> REMOVE
At any point after the initial ADD, a transition to CANCEL is also possible.
Fields
event_time: u64device_id: u32pointer_id: u32type_: PointerEventTypephase: PointerEventPhasex: f32y: f32radius_major: f32radius_minor: f32Trait Implementations
Sourceimpl Clone for PointerEvent
impl Clone for PointerEvent
Sourcefn clone(&self) -> PointerEvent
fn clone(&self) -> PointerEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PointerEvent
Sourceimpl Debug for PointerEvent
impl Debug for PointerEvent
Sourceimpl<___E> Encode<PointerEvent, ___E> for PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PointerEvent, ___E> for PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PointerEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PointerEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<PointerEvent, ___E> for &'a PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PointerEvent, ___E> for &'a PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PointerEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PointerEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, PointerEvent>, ___E> for PointerEvent
impl<___E> EncodeOption<Box<'static, PointerEvent>, ___E> for PointerEvent
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PointerEvent>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PointerEvent>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PointerEvent>, ___E> for &'a PointerEvent
impl<'a, ___E> EncodeOption<Box<'static, PointerEvent>, ___E> for &'a PointerEvent
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PointerEvent>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PointerEvent>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<PointerEvent> for PointerEvent
impl FromWire<PointerEvent> for PointerEvent
Sourcefn from_wire(wire: PointerEvent) -> Self
fn from_wire(wire: PointerEvent) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PointerEvent> for PointerEvent
impl FromWireRef<PointerEvent> for PointerEvent
Sourcefn from_wire_ref(wire: &PointerEvent) -> Self
fn from_wire_ref(wire: &PointerEvent) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for PointerEvent
impl PartialEq for PointerEvent
Sourceimpl PartialOrd for PointerEvent
impl PartialOrd for PointerEvent
impl StructuralPartialEq for PointerEvent