pub struct SendPointerInputCmd {
pub compositor_id: u32,
pub pointer_event: PointerEvent,
}Fields
compositor_id: u32pointer_event: PointerEventTrait Implementations
Sourceimpl Clone for SendPointerInputCmd
impl Clone for SendPointerInputCmd
Sourcefn clone(&self) -> SendPointerInputCmd
fn clone(&self) -> SendPointerInputCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SendPointerInputCmd
Sourceimpl Debug for SendPointerInputCmd
impl Debug for SendPointerInputCmd
Sourceimpl<___E> Encode<SendPointerInputCmd, ___E> for SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SendPointerInputCmd, ___E> for SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendPointerInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendPointerInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<SendPointerInputCmd, ___E> for &'a SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SendPointerInputCmd, ___E> for &'a SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendPointerInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendPointerInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SendPointerInputCmd>, ___E> for SendPointerInputCmd
impl<___E> EncodeOption<Box<'static, SendPointerInputCmd>, ___E> for SendPointerInputCmd
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SendPointerInputCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SendPointerInputCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SendPointerInputCmd>, ___E> for &'a SendPointerInputCmd
impl<'a, ___E> EncodeOption<Box<'static, SendPointerInputCmd>, ___E> for &'a SendPointerInputCmd
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SendPointerInputCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SendPointerInputCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SendPointerInputCmd> for SendPointerInputCmd
impl FromWire<SendPointerInputCmd> for SendPointerInputCmd
Sourcefn from_wire(wire: SendPointerInputCmd) -> Self
fn from_wire(wire: SendPointerInputCmd) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SendPointerInputCmd> for SendPointerInputCmd
impl FromWireRef<SendPointerInputCmd> for SendPointerInputCmd
Sourcefn from_wire_ref(wire: &SendPointerInputCmd) -> Self
fn from_wire_ref(wire: &SendPointerInputCmd) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for SendPointerInputCmd
impl PartialEq for SendPointerInputCmd
Sourceimpl PartialOrd for SendPointerInputCmd
impl PartialOrd for SendPointerInputCmd
impl StructuralPartialEq for SendPointerInputCmd