#[repr(C)]pub struct SetParallelDispatchCmd {
pub parallel_dispatch: bool,
}Fields
parallel_dispatch: boolTrait Implementations
Sourceimpl Clone for SetParallelDispatchCmd
impl Clone for SetParallelDispatchCmd
Sourcefn clone(&self) -> SetParallelDispatchCmd
fn clone(&self) -> SetParallelDispatchCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SetParallelDispatchCmd
Sourceimpl Debug for SetParallelDispatchCmd
impl Debug for SetParallelDispatchCmd
Sourceimpl<___E> Encode<SetParallelDispatchCmd, ___E> for SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SetParallelDispatchCmd, ___E> for SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SetParallelDispatchCmd>
const COPY_OPTIMIZATION: CopyOptimization<Self, SetParallelDispatchCmd>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetParallelDispatchCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetParallelDispatchCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SetParallelDispatchCmd, ___E> for &'a SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SetParallelDispatchCmd, ___E> for &'a SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetParallelDispatchCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetParallelDispatchCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SetParallelDispatchCmd>, ___E> for SetParallelDispatchCmd
impl<___E> EncodeOption<Box<'static, SetParallelDispatchCmd>, ___E> for SetParallelDispatchCmd
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SetParallelDispatchCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SetParallelDispatchCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SetParallelDispatchCmd>, ___E> for &'a SetParallelDispatchCmd
impl<'a, ___E> EncodeOption<Box<'static, SetParallelDispatchCmd>, ___E> for &'a SetParallelDispatchCmd
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SetParallelDispatchCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SetParallelDispatchCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SetParallelDispatchCmd
Sourceimpl FromWire<SetParallelDispatchCmd> for SetParallelDispatchCmd
impl FromWire<SetParallelDispatchCmd> for SetParallelDispatchCmd
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SetParallelDispatchCmd, Self>
const COPY_OPTIMIZATION: CopyOptimization<SetParallelDispatchCmd, Self>
Sourcefn from_wire(wire: SetParallelDispatchCmd) -> Self
fn from_wire(wire: SetParallelDispatchCmd) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SetParallelDispatchCmd> for SetParallelDispatchCmd
impl FromWireRef<SetParallelDispatchCmd> for SetParallelDispatchCmd
Sourcefn from_wire_ref(wire: &SetParallelDispatchCmd) -> Self
fn from_wire_ref(wire: &SetParallelDispatchCmd) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SetParallelDispatchCmd
impl Hash for SetParallelDispatchCmd
Sourceimpl Ord for SetParallelDispatchCmd
impl Ord for SetParallelDispatchCmd
Sourcefn cmp(&self, other: &SetParallelDispatchCmd) -> Ordering
fn cmp(&self, other: &SetParallelDispatchCmd) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for SetParallelDispatchCmd
impl PartialEq for SetParallelDispatchCmd
Sourceimpl PartialOrd for SetParallelDispatchCmd
impl PartialOrd for SetParallelDispatchCmd
impl StructuralPartialEq for SetParallelDispatchCmd