pub struct StylusReport {
pub x: i32,
pub y: i32,
pub pressure: u32,
pub is_in_contact: bool,
pub in_range: bool,
pub is_inverted: bool,
pub pressed_buttons: u32,
}Fields
x: i32y: i32pressure: u32is_in_contact: boolin_range: boolis_inverted: boolTrait Implementations
Sourceimpl Clone for StylusReport
impl Clone for StylusReport
Sourcefn clone(&self) -> StylusReport
fn clone(&self) -> StylusReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StylusReport
Sourceimpl Debug for StylusReport
impl Debug for StylusReport
Sourceimpl<___E> Encode<StylusReport, ___E> for StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StylusReport, ___E> for StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StylusReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StylusReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<StylusReport, ___E> for &'a StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StylusReport, ___E> for &'a StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StylusReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StylusReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, StylusReport>, ___E> for StylusReport
impl<___E> EncodeOption<Box<'static, StylusReport>, ___E> for StylusReport
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StylusReport>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StylusReport>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StylusReport>, ___E> for &'a StylusReport
impl<'a, ___E> EncodeOption<Box<'static, StylusReport>, ___E> for &'a StylusReport
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StylusReport>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StylusReport>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for StylusReport
Sourceimpl FromWire<StylusReport> for StylusReport
impl FromWire<StylusReport> for StylusReport
Sourcefn from_wire(wire: StylusReport) -> Self
fn from_wire(wire: StylusReport) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<StylusReport> for StylusReport
impl FromWireRef<StylusReport> for StylusReport
Sourcefn from_wire_ref(wire: &StylusReport) -> Self
fn from_wire_ref(wire: &StylusReport) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StylusReport
impl Hash for StylusReport
Sourceimpl Ord for StylusReport
impl Ord for StylusReport
Sourcefn cmp(&self, other: &StylusReport) -> Ordering
fn cmp(&self, other: &StylusReport) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for StylusReport
impl PartialEq for StylusReport
Sourceimpl PartialOrd for StylusReport
impl PartialOrd for StylusReport
impl StructuralPartialEq for StylusReport