#[repr(C)]pub struct TextRange {
pub start: i64,
pub end: i64,
}Expand description
A range of characters in a string of text. Although strings in FIDL’s wire format are UTF-8 encoded, these indices are measured in UTF-16 code units for legacy reasons. These text input APIs will eventually be replaced by fuchsia.ui.text, which uses code points instead.
Fields
start: i64end: i64Trait Implementations
impl Copy for TextRange
Sourceimpl<___E> Encode<TextRange, ___E> for TextRangewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TextRange, ___E> for TextRangewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, TextRange>
const COPY_OPTIMIZATION: CopyOptimization<Self, TextRange>
Sourceimpl<'a, ___E> Encode<TextRange, ___E> for &'a TextRangewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TextRange, ___E> for &'a TextRangewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> EncodeOption<Box<'static, TextRange>, ___E> for TextRange
impl<___E> EncodeOption<Box<'static, TextRange>, ___E> for TextRange
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TextRange>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TextRange>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TextRange>, ___E> for &'a TextRange
impl<'a, ___E> EncodeOption<Box<'static, TextRange>, ___E> for &'a TextRange
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TextRange>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TextRange>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for TextRange
Sourceimpl FromWireRef<TextRange> for TextRange
impl FromWireRef<TextRange> for TextRange
Sourcefn from_wire_ref(wire: &TextRange) -> Self
fn from_wire_ref(wire: &TextRange) -> Self
Converts the given reference to this type.
Sourceimpl Ord for TextRange
impl Ord for TextRange
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for TextRange
impl PartialOrd for TextRange
impl StructuralPartialEq for TextRange