pub struct TextSelection {
pub base: i64,
pub extent: i64,
pub affinity: TextAffinity,
}Expand description
A range of text that represents a selection. Although strings in FIDL’s wire format are UTF-8 encoded, these indices are measured in UTF-16 code units for legacy reasons. These text input APIs will eventually be replaced by fuchsia.ui.text, which uses code points instead.
Text selection is always directional. Direction should be determined by comparing base and extent.
Fields
base: i64extent: i64affinity: TextAffinityTrait Implementations
Sourceimpl Clone for TextSelection
impl Clone for TextSelection
Sourcefn clone(&self) -> TextSelection
fn clone(&self) -> TextSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TextSelection
Sourceimpl Debug for TextSelection
impl Debug for TextSelection
Sourceimpl<___E> Encode<TextSelection, ___E> for TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TextSelection, ___E> for TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextSelection>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextSelection>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<TextSelection, ___E> for &'a TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TextSelection, ___E> for &'a TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextSelection>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextSelection>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TextSelection>, ___E> for TextSelection
impl<___E> EncodeOption<Box<'static, TextSelection>, ___E> for TextSelection
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TextSelection>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TextSelection>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TextSelection>, ___E> for &'a TextSelection
impl<'a, ___E> EncodeOption<Box<'static, TextSelection>, ___E> for &'a TextSelection
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TextSelection>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TextSelection>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for TextSelection
Sourceimpl FromWire<TextSelection> for TextSelection
impl FromWire<TextSelection> for TextSelection
Sourcefn from_wire(wire: TextSelection) -> Self
fn from_wire(wire: TextSelection) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<TextSelection> for TextSelection
impl FromWireRef<TextSelection> for TextSelection
Sourcefn from_wire_ref(wire: &TextSelection) -> Self
fn from_wire_ref(wire: &TextSelection) -> Self
Converts the given reference to this type.
Sourceimpl Hash for TextSelection
impl Hash for TextSelection
Sourceimpl Ord for TextSelection
impl Ord for TextSelection
Sourcefn cmp(&self, other: &TextSelection) -> Ordering
fn cmp(&self, other: &TextSelection) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for TextSelection
impl PartialEq for TextSelection
Sourceimpl PartialOrd for TextSelection
impl PartialOrd for TextSelection
impl StructuralPartialEq for TextSelection