#[repr(C)]pub struct Touch {
pub finger_id: u32,
pub x: i32,
pub y: i32,
pub width: u32,
pub height: u32,
}Fields
finger_id: u32x: i32y: i32width: u32height: u32Trait Implementations
impl Copy for Touch
Sourceimpl<___E> Encode<Touch, ___E> for Touchwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Touch, ___E> for Touchwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Touch>
const COPY_OPTIMIZATION: CopyOptimization<Self, Touch>
Sourceimpl<'a, ___E> Encode<Touch, ___E> for &'a Touchwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Touch, ___E> for &'a Touchwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> EncodeOption<Box<'static, Touch>, ___E> for Touch
impl<___E> EncodeOption<Box<'static, Touch>, ___E> for Touch
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Touch>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Touch>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Touch>, ___E> for &'a Touch
impl<'a, ___E> EncodeOption<Box<'static, Touch>, ___E> for &'a Touch
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Touch>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Touch>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for Touch
Sourceimpl FromWireRef<Touch> for Touch
impl FromWireRef<Touch> for Touch
Sourcefn from_wire_ref(wire: &Touch) -> Self
fn from_wire_ref(wire: &Touch) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Touch
impl Ord for Touch
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Touch
impl PartialOrd for Touch
impl StructuralPartialEq for Touch