#[repr(C)]pub struct KeyboardEvent {
pub event_time: Uint64,
pub device_id: Uint32,
pub phase: KeyboardEventPhase,
pub hid_usage: Uint32,
pub code_point: Uint32,
pub modifiers: Uint32,
}Expand description
The wire type corresponding to KeyboardEvent.
Fields
event_time: Uint64device_id: Uint32phase: KeyboardEventPhasehid_usage: Uint32code_point: Uint32modifiers: Uint32Trait Implementations
Sourceimpl Clone for KeyboardEvent
impl Clone for KeyboardEvent
Sourcefn clone(&self) -> KeyboardEvent
fn clone(&self) -> KeyboardEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for KeyboardEvent
impl Constrained for KeyboardEvent
Sourceimpl Debug for KeyboardEvent
impl Debug for KeyboardEvent
Sourceimpl<___D> Decode<___D> for KeyboardEventwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for KeyboardEventwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<KeyboardEvent, ___E> for KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<KeyboardEvent, ___E> for KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyboardEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyboardEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<KeyboardEvent, ___E> for &'a KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<KeyboardEvent, ___E> for &'a KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyboardEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyboardEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5> Encode<KeyboardEvent, ___E> for KeyboardEvent<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
T1: Encode<Uint32, ___E>,
T2: Encode<KeyboardEventPhase, ___E>,
T3: Encode<Uint32, ___E>,
T4: Encode<Uint32, ___E>,
T5: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5> Encode<KeyboardEvent, ___E> for KeyboardEvent<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
T1: Encode<Uint32, ___E>,
T2: Encode<KeyboardEventPhase, ___E>,
T3: Encode<Uint32, ___E>,
T4: Encode<Uint32, ___E>,
T5: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyboardEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyboardEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<KeyboardEvent> for KeyboardEvent
impl FromWire<KeyboardEvent> for KeyboardEvent
Sourcefn from_wire(wire: KeyboardEvent) -> Self
fn from_wire(wire: KeyboardEvent) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<KeyboardEvent> for KeyboardEvent
impl FromWireRef<KeyboardEvent> for KeyboardEvent
Sourcefn from_wire_ref(wire: &KeyboardEvent) -> Self
fn from_wire_ref(wire: &KeyboardEvent) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for KeyboardEvent
impl IntoNatural for KeyboardEvent
Sourcetype Natural = KeyboardEvent
type Natural = KeyboardEvent
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for KeyboardEvent
impl Wire for KeyboardEvent
Sourcetype Narrowed<'de> = KeyboardEvent
type Narrowed<'de> = KeyboardEvent
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.