#[repr(C)]pub struct MouseReport {
pub rel_x: Int32,
pub rel_y: Int32,
pub rel_hscroll: Int32,
pub rel_vscroll: Int32,
pub pressed_buttons: Uint32,
}Expand description
The wire type corresponding to MouseReport.
Fields
rel_x: Int32rel_y: Int32rel_hscroll: Int32rel_vscroll: Int32Trait Implementations
Sourceimpl Clone for MouseReport
impl Clone for MouseReport
Sourcefn clone(&self) -> MouseReport
fn clone(&self) -> MouseReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for MouseReport
impl Constrained for MouseReport
Sourceimpl Debug for MouseReport
impl Debug for MouseReport
Sourceimpl<___D> Decode<___D> for MouseReportwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for MouseReportwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<MouseReport, ___E> for MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MouseReport, ___E> for MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MouseReport>
const COPY_OPTIMIZATION: CopyOptimization<Self, MouseReport>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MouseReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MouseReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<MouseReport, ___E> for &'a MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MouseReport, ___E> for &'a MouseReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MouseReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MouseReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4> Encode<MouseReport, ___E> for MouseReport<T0, T1, T2, T3, T4>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<Int32, ___E>,
T2: Encode<Int32, ___E>,
T3: Encode<Int32, ___E>,
T4: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2, T3, T4> Encode<MouseReport, ___E> for MouseReport<T0, T1, T2, T3, T4>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<Int32, ___E>,
T2: Encode<Int32, ___E>,
T3: Encode<Int32, ___E>,
T4: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MouseReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MouseReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<MouseReport> for MouseReport
impl FromWire<MouseReport> for MouseReport
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MouseReport, Self>
const COPY_OPTIMIZATION: CopyOptimization<MouseReport, Self>
Sourcefn from_wire(wire: MouseReport) -> Self
fn from_wire(wire: MouseReport) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<MouseReport> for MouseReport
impl FromWireRef<MouseReport> for MouseReport
Sourcefn from_wire_ref(wire: &MouseReport) -> Self
fn from_wire_ref(wire: &MouseReport) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for MouseReport
impl IntoNatural for MouseReport
Sourcetype Natural = MouseReport
type Natural = MouseReport
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for MouseReport
impl Wire for MouseReport
Sourcetype Narrowed<'de> = MouseReport
type Narrowed<'de> = MouseReport
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.