#[repr(C)]pub struct PointerEvent {
pub event_time: Uint64,
pub device_id: Uint32,
pub pointer_id: Uint32,
pub type_: PointerEventType,
pub phase: PointerEventPhase,
pub x: Float32,
pub y: Float32,
pub radius_major: Float32,
pub radius_minor: Float32,
pub buttons: Uint32,
}Expand description
The wire type corresponding to PointerEvent.
Fields
event_time: Uint64device_id: Uint32pointer_id: Uint32type_: PointerEventTypephase: PointerEventPhasex: Float32y: Float32radius_major: Float32radius_minor: Float32Trait Implementations
Sourceimpl Clone for PointerEvent
impl Clone for PointerEvent
Sourcefn clone(&self) -> PointerEvent
fn clone(&self) -> PointerEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for PointerEvent
impl Constrained for PointerEvent
Sourceimpl Debug for PointerEvent
impl Debug for PointerEvent
Sourceimpl<___D> Decode<___D> for PointerEventwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for PointerEventwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<PointerEvent, ___E> for PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PointerEvent, ___E> for PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PointerEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PointerEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<PointerEvent, ___E> for &'a PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PointerEvent, ___E> for &'a PointerEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PointerEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PointerEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Encode<PointerEvent, ___E> for PointerEvent<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
T1: Encode<Uint32, ___E>,
T2: Encode<Uint32, ___E>,
T3: Encode<PointerEventType, ___E>,
T4: Encode<PointerEventPhase, ___E>,
T5: Encode<Float32, ___E>,
T6: Encode<Float32, ___E>,
T7: Encode<Float32, ___E>,
T8: Encode<Float32, ___E>,
T9: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Encode<PointerEvent, ___E> for PointerEvent<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
T1: Encode<Uint32, ___E>,
T2: Encode<Uint32, ___E>,
T3: Encode<PointerEventType, ___E>,
T4: Encode<PointerEventPhase, ___E>,
T5: Encode<Float32, ___E>,
T6: Encode<Float32, ___E>,
T7: Encode<Float32, ___E>,
T8: Encode<Float32, ___E>,
T9: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PointerEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PointerEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<PointerEvent> for PointerEvent
impl FromWire<PointerEvent> for PointerEvent
Sourcefn from_wire(wire: PointerEvent) -> Self
fn from_wire(wire: PointerEvent) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PointerEvent> for PointerEvent
impl FromWireRef<PointerEvent> for PointerEvent
Sourcefn from_wire_ref(wire: &PointerEvent) -> Self
fn from_wire_ref(wire: &PointerEvent) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for PointerEvent
impl IntoNatural for PointerEvent
Sourcetype Natural = PointerEvent
type Natural = PointerEvent
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for PointerEvent
impl Wire for PointerEvent
Sourcetype Narrowed<'de> = PointerEvent
type Narrowed<'de> = PointerEvent
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.