#[repr(C)]pub struct SendKeyboardInputCmd {
pub compositor_id: Uint32,
pub keyboard_event: KeyboardEvent,
}Expand description
The wire type corresponding to SendKeyboardInputCmd.
Fields
compositor_id: Uint32keyboard_event: KeyboardEventTrait Implementations
Sourceimpl Clone for SendKeyboardInputCmd
impl Clone for SendKeyboardInputCmd
Sourcefn clone(&self) -> SendKeyboardInputCmd
fn clone(&self) -> SendKeyboardInputCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SendKeyboardInputCmd
impl Constrained for SendKeyboardInputCmd
Sourceimpl Debug for SendKeyboardInputCmd
impl Debug for SendKeyboardInputCmd
Sourceimpl<___D> Decode<___D> for SendKeyboardInputCmdwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SendKeyboardInputCmdwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SendKeyboardInputCmd, ___E> for SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SendKeyboardInputCmd, ___E> for SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendKeyboardInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendKeyboardInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<SendKeyboardInputCmd, ___E> for &'a SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SendKeyboardInputCmd, ___E> for &'a SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendKeyboardInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendKeyboardInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SendKeyboardInputCmd, ___E> for SendKeyboardInputCmd<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<KeyboardEvent, ___E>,
impl<___E, T0, T1> Encode<SendKeyboardInputCmd, ___E> for SendKeyboardInputCmd<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<KeyboardEvent, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendKeyboardInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendKeyboardInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SendKeyboardInputCmd> for SendKeyboardInputCmd
impl FromWire<SendKeyboardInputCmd> for SendKeyboardInputCmd
Sourcefn from_wire(wire: SendKeyboardInputCmd) -> Self
fn from_wire(wire: SendKeyboardInputCmd) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SendKeyboardInputCmd> for SendKeyboardInputCmd
impl FromWireRef<SendKeyboardInputCmd> for SendKeyboardInputCmd
Sourcefn from_wire_ref(wire: &SendKeyboardInputCmd) -> Self
fn from_wire_ref(wire: &SendKeyboardInputCmd) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SendKeyboardInputCmd
impl IntoNatural for SendKeyboardInputCmd
Sourcetype Natural = SendKeyboardInputCmd
type Natural = SendKeyboardInputCmd
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SendKeyboardInputCmd
impl Wire for SendKeyboardInputCmd
Sourcetype Narrowed<'de> = SendKeyboardInputCmd
type Narrowed<'de> = SendKeyboardInputCmd
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.