#[repr(C)]pub struct SendPointerInputCmd {
pub compositor_id: Uint32,
pub pointer_event: PointerEvent,
}Expand description
The wire type corresponding to SendPointerInputCmd.
Fields
compositor_id: Uint32pointer_event: PointerEventTrait Implementations
Sourceimpl Clone for SendPointerInputCmd
impl Clone for SendPointerInputCmd
Sourcefn clone(&self) -> SendPointerInputCmd
fn clone(&self) -> SendPointerInputCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SendPointerInputCmd
impl Constrained for SendPointerInputCmd
Sourceimpl Debug for SendPointerInputCmd
impl Debug for SendPointerInputCmd
Sourceimpl<___D> Decode<___D> for SendPointerInputCmdwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SendPointerInputCmdwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SendPointerInputCmd, ___E> for SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SendPointerInputCmd, ___E> for SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendPointerInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendPointerInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<SendPointerInputCmd, ___E> for &'a SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SendPointerInputCmd, ___E> for &'a SendPointerInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendPointerInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendPointerInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SendPointerInputCmd, ___E> for SendPointerInputCmd<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<PointerEvent, ___E>,
impl<___E, T0, T1> Encode<SendPointerInputCmd, ___E> for SendPointerInputCmd<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<PointerEvent, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendPointerInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendPointerInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SendPointerInputCmd> for SendPointerInputCmd
impl FromWire<SendPointerInputCmd> for SendPointerInputCmd
Sourcefn from_wire(wire: SendPointerInputCmd) -> Self
fn from_wire(wire: SendPointerInputCmd) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SendPointerInputCmd> for SendPointerInputCmd
impl FromWireRef<SendPointerInputCmd> for SendPointerInputCmd
Sourcefn from_wire_ref(wire: &SendPointerInputCmd) -> Self
fn from_wire_ref(wire: &SendPointerInputCmd) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SendPointerInputCmd
impl IntoNatural for SendPointerInputCmd
Sourcetype Natural = SendPointerInputCmd
type Natural = SendPointerInputCmd
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SendPointerInputCmd
impl Wire for SendPointerInputCmd
Sourcetype Narrowed<'de> = SendPointerInputCmd
type Narrowed<'de> = SendPointerInputCmd
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.