#[repr(C)]pub struct SetParallelDispatchCmd {
pub parallel_dispatch: bool,
}Expand description
The wire type corresponding to SetParallelDispatchCmd.
Fields
parallel_dispatch: boolTrait Implementations
Sourceimpl Clone for SetParallelDispatchCmd
impl Clone for SetParallelDispatchCmd
Sourcefn clone(&self) -> SetParallelDispatchCmd
fn clone(&self) -> SetParallelDispatchCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SetParallelDispatchCmd
impl Constrained for SetParallelDispatchCmd
Sourceimpl Debug for SetParallelDispatchCmd
impl Debug for SetParallelDispatchCmd
Sourceimpl<___D> Decode<___D> for SetParallelDispatchCmdwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SetParallelDispatchCmdwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SetParallelDispatchCmd, ___E> for SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SetParallelDispatchCmd, ___E> for SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SetParallelDispatchCmd>
const COPY_OPTIMIZATION: CopyOptimization<Self, SetParallelDispatchCmd>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetParallelDispatchCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetParallelDispatchCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SetParallelDispatchCmd, ___E> for &'a SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SetParallelDispatchCmd, ___E> for &'a SetParallelDispatchCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetParallelDispatchCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetParallelDispatchCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<SetParallelDispatchCmd, ___E> for SetParallelDispatchCmd<T0>
impl<___E, T0> Encode<SetParallelDispatchCmd, ___E> for SetParallelDispatchCmd<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetParallelDispatchCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetParallelDispatchCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SetParallelDispatchCmd> for SetParallelDispatchCmd
impl FromWire<SetParallelDispatchCmd> for SetParallelDispatchCmd
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SetParallelDispatchCmd, Self>
const COPY_OPTIMIZATION: CopyOptimization<SetParallelDispatchCmd, Self>
Sourcefn from_wire(wire: SetParallelDispatchCmd) -> Self
fn from_wire(wire: SetParallelDispatchCmd) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SetParallelDispatchCmd> for SetParallelDispatchCmd
impl FromWireRef<SetParallelDispatchCmd> for SetParallelDispatchCmd
Sourcefn from_wire_ref(wire: &SetParallelDispatchCmd) -> Self
fn from_wire_ref(wire: &SetParallelDispatchCmd) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SetParallelDispatchCmd
impl IntoNatural for SetParallelDispatchCmd
Sourcetype Natural = SetParallelDispatchCmd
type Natural = SetParallelDispatchCmd
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SetParallelDispatchCmd
impl Wire for SetParallelDispatchCmd
Sourcetype Narrowed<'de> = SetParallelDispatchCmd
type Narrowed<'de> = SetParallelDispatchCmd
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.