pub trait DeviceIteratorLocalServerHandler<___T: Transport = Channel> {
// Required method
fn get_next(
&mut self,
responder: Responder<GetNext, ___T>,
) -> impl Future<Output = ()>;
}Expand description
A server handler for the DeviceIterator protocol.
See DeviceIterator for more details.
Required Methods
Sourcefn get_next(
&mut self,
responder: Responder<GetNext, ___T>,
) -> impl Future<Output = ()>
fn get_next( &mut self, responder: Responder<GetNext, ___T>, ) -> impl Future<Output = ()>
Returns the next batch of active devices.
Returns an empty vector when all existing devices have been iterated
through. The client should then close this channel and rely on the
DeviceListener for subsequent events.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".